==> huaweicloudsdkidmeclassicapi-3.1.75-py2.py3-none-any.whl: huaweicloudsdkidmeclassicapi/v1/model/persist_object_ids_decrypt_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PersistObjectIdsDecryptDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'decrypt': 'bool',
        'ids': 'list[str]'
    }

    attribute_map = {
        'decrypt': 'decrypt',
        'ids': 'ids'
    }

    def __init__(self, decrypt=None, ids=None):
        """PersistObjectIdsDecryptDTO

        The model defined in huaweicloud sdk

        :param decrypt: 是否加密。 - true：加密。 - false：不加密。
        :type decrypt: bool
        :param ids: ID列表。
        :type ids: list[str]
        """
        
        

        self._decrypt = None
        self._ids = None
        self.discriminator = None

        if decrypt is not None:
            self.decrypt = decrypt
        self.ids = ids

    @property
    def decrypt(self):
        """Gets the decrypt of this PersistObjectIdsDecryptDTO.

        是否加密。 - true：加密。 - false：不加密。

        :return: The decrypt of this PersistObjectIdsDecryptDTO.
        :rtype: bool
        """
        return self._decrypt

    @decrypt.setter
    def decrypt(self, decrypt):
        """Sets the decrypt of this PersistObjectIdsDecryptDTO.

        是否加密。 - true：加密。 - false：不加密。

        :param decrypt: The decrypt of this PersistObjectIdsDecryptDTO.
        :type decrypt: bool
        """
        self._decrypt = decrypt

    @property
    def ids(self):
        """Gets the ids of this PersistObjectIdsDecryptDTO.

        ID列表。

        :return: The ids of this PersistObjectIdsDecryptDTO.
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this PersistObjectIdsDecryptDTO.

        ID列表。

        :param ids: The ids of this PersistObjectIdsDecryptDTO.
        :type ids: list[str]
        """
        self._ids = ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersistObjectIdsDecryptDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkidmeclassicapi-3.1.84-py2.py3-none-any.whl: huaweicloudsdkidmeclassicapi/v1/model/persist_object_ids_decrypt_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PersistObjectIdsDecryptDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'decrypt': 'bool',
        'ids': 'list[int]'
    }

    attribute_map = {
        'decrypt': 'decrypt',
        'ids': 'ids'
    }

    def __init__(self, decrypt=None, ids=None):
        """PersistObjectIdsDecryptDTO

        The model defined in huaweicloud sdk

        :param decrypt: 是否加密。 - true：加密。 - false：不加密。
        :type decrypt: bool
        :param ids: ID列表。
        :type ids: list[int]
        """
        
        

        self._decrypt = None
        self._ids = None
        self.discriminator = None

        if decrypt is not None:
            self.decrypt = decrypt
        self.ids = ids

    @property
    def decrypt(self):
        """Gets the decrypt of this PersistObjectIdsDecryptDTO.

        是否加密。 - true：加密。 - false：不加密。

        :return: The decrypt of this PersistObjectIdsDecryptDTO.
        :rtype: bool
        """
        return self._decrypt

    @decrypt.setter
    def decrypt(self, decrypt):
        """Sets the decrypt of this PersistObjectIdsDecryptDTO.

        是否加密。 - true：加密。 - false：不加密。

        :param decrypt: The decrypt of this PersistObjectIdsDecryptDTO.
        :type decrypt: bool
        """
        self._decrypt = decrypt

    @property
    def ids(self):
        """Gets the ids of this PersistObjectIdsDecryptDTO.

        ID列表。

        :return: The ids of this PersistObjectIdsDecryptDTO.
        :rtype: list[int]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this PersistObjectIdsDecryptDTO.

        ID列表。

        :param ids: The ids of this PersistObjectIdsDecryptDTO.
        :type ids: list[int]
        """
        self._ids = ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersistObjectIdsDecryptDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
